@@ -1,5 +1,5 @@
 import time
-from .clients import hw_ecs_client
+from .clients import hw_ecs_client, hw_bss_client
 
 
 class HuaweiEcs:
@@ -128,3 +128,9 @@ class HuaweiEcs:
             if interface.port_state == self.PORT_STATE_AVAILABLE:
                 return interface.port_id
         return
+
+    def prepaid_resource(self):
+        return hw_bss_client.query_resource(self.id)
+
+    def cancel_resource(self):
+        return hw_bss_client.cancel_resource(self.id)
